Command-line interface - Faber 1.0 documentation

###  |

# Command-line interface

Faber is a construction tool.

    usage: faber [-h] [--srcdir SRCDIR] [--builddir BUILDDIR] [--rc RC]
                 [--log {summary,actions,commands,process,scheduler,tools,features,rules,config,test} | -l LOGLEVEL | -s]
                 [-j PARALLEL] [--debug] [-f] [-n] [-i] [-c] [-t TIMEOUT] [-p]
                 [--info [WHAT]] [--shell] [-v]
                 [GOAL [GOAL ...]] [PARAMETER=VALUE [PARAMETER=VALUE ...]]

Positional arguments:

  `goals` | a goal to update
  `parameters` | a parameter value

Options:

  `--srcdir=.` | the location of the source directory
  `--builddir=.` | the location of the build directory
  `--rc` | the location of the rc file
  `--log` | add log topic Possible choices: summary, actions, commands, process, scheduler, tools, features, rules, config, test
  `-l` | set log level (summary=1, actions=2, commands=4)
  `-s=False, --silent=False`
  | suppress all output
  `-j=1, --parallel=1`
  | set concurrency level
  `--debug=False` | do not suppress traceback on error
  `-f=False, --force=False`
  | update goals even if they are current
  `-n=False, --noexec=False`
  | do not actually execute actions
  `-i=False, --intermediates=False`
  | do not remove intermediate files after build
  `-c, --clean` | cleanup
  `-t=0, --timeout=0`
  | set timeout for individual actions
  `-p=False, --profile=False`
  | log timing info with command
  `--info` | print information about the build logic Possible choices: goals, tools
  `--shell=False` | run interactive shell
  `-v, --version` | show program's version number and exit